@@ -52,7 +52,7 @@ setGeneric("dimnames")
 # Conversion to and from sts objects
 ######################################################################
 
-#setGeneric("as.sts") 
+#setGeneric("as.sts")
 setGeneric("as.data.frame")
 
 
@@ -70,19 +70,34 @@ setMethod("epoch", "sts", function(x, as.Date=x@epochAsDate) {
     } else if (x@freq == 12) { # use the first day of every month
       as.Date(strptime(paste(year(x), epochInYear(x), 1, sep = "-"),
                        format = "%Y-%m-%d"))
-    } else if (x@freq == 52) { # use Mondays
-      firstMonday <- strptime(x = paste0(x@start[1L], "-W", x@start[2L], "-1"),
-                              format = "%Y-W%W-%u")
-      seq(from = as.Date(firstMonday), by = 7L, length.out = nrow(x))
+    } else if (x@freq %in% c(26, 52)) { # use Mondays
+      ## be consistent with epochInYear(): 'start' means *ISO* year and week!
+      ## Unfortunately, %G and %V are not supported for input via strptime():
+      ## firstMonday <- strptime(x = paste0(x@start[1L], "-W", x@start[2L], "-1"),
+      ##                         format = "%G-W%V-%u")  # WRONG, gives today
+      ## so we run a naive search for the Monday of the 'start' week
+      startweek <- x@start[2L]
+      if (x@freq == 26) startweek <- 2*startweek - 1
+      candidates <- seq.Date(as.Date(paste0(x@start[1L]-1L, "-12-29")),
+                             as.Date(paste0(x@start[1L], "-12-28")), by = 1L)
+      firstMonday <- candidates[match(sprintf("%i-W%02i", x@start[1L], startweek),
+                                      strftime(candidates, "%G-W%V"))]
+      seq.Date(from = firstMonday, by = (52/x@freq) * 7L, length.out = nrow(x))
     } else if (x@freq == 365) { # use day of the year (incorrect in leap years)
       as.Date(strptime(paste0(year(x), "-D", epochInYear(x)), format = "%Y-D%j"))
     } else {
-      stop("date conversion only implemented for daily, weekly and monthly data")
+      stop("date conversion only implemented for daily, (bi-)weekly and monthly data")
     }
   }
 })
 setGeneric("epoch<-", function(x, value) standardGeneric("epoch<-"))
 setReplaceMethod("epoch", "sts", function(x, value) {
+ if (length(value) != nrow(x@observed))
+   stop("'epoch' must be of length 'nrow(observed)'")
+ if (inherits(value, "Date")) {
+   value <- as.integer(value)
+   x@epochAsDate <- TRUE
+ }
  x@epoch <- value
  x
 })
@@ -148,7 +163,7 @@ setReplaceMethod("multinomialTS", "sts", function(x, value) {
  x
 })
 
-### neighbourhood matrix slot 
+### neighbourhood matrix slot
 setGeneric("neighbourhood", function(x) standardGeneric("neighbourhood"))
 setMethod("neighbourhood", "sts", function(x) {
   return(x@neighbourhood)
@@ -172,20 +187,26 @@ setGeneric("year", function(x, ...) standardGeneric("year"))
 # For stsNC class
 ######################################################################
 
-### access function for repotringTriangle slot 
+### access function for repotringTriangle slot
 setGeneric("reportingTriangle", function(x) standardGeneric("reportingTriangle"))
 setMethod("reportingTriangle", "stsNC", function(x) {
   return(x@reportingTriangle)
 })
 
-### access function for delayCDF slot 
+### access function for delayCDF slot
 setGeneric("delayCDF", function(x) standardGeneric("delayCDF"))
 setMethod("delayCDF", "stsNC", function(x) {
   return(x@delayCDF)
 })
 
-### access function for SR slot 
+### access function for SR slot
 setGeneric("score", function(x) standardGeneric("score"))
 setMethod("score", "stsNC", function(x) {
   return(x@SR)
 })
+
+### access function for prediction interval slot
+setGeneric("predint", function(x) standardGeneric("predint"))
+setMethod("predint", "stsNC", function(x) {
+  return(x@pi)
+})
