@@ -6,9 +6,9 @@
 ### Standard S3-methods for "epidataCS" objects, which represent
 ### CONTINUOUS SPATIO-temporal infectious disease case data
 ###
-### Copyright (C) 2009-2015,2017-2018 Sebastian Meyer
-### $Revision: 2156 $
-### $Date: 2018-05-25 17:26:20 +0200 (Fri, 25. May 2018) $
+### Copyright (C) 2009-2015,2017-2019 Sebastian Meyer
+### $Revision: 2958 $
+### $Date: 2023-03-10 08:43:46 +0100 (Fri, 10. Mar 2023) $
 ################################################################################
 
 
@@ -158,19 +158,22 @@ subset.epidataCS <- function (x, subset, select, drop = TRUE, ...)
 
 
 ## Subset epidataCS object using head and tail methods (which use [.epidataCS)
+## adapted from the corresponding matrix-methods, which have
+## Copyright (C) 1995-2012 The R Core Team
 
 head.epidataCS <- function (x, n = 6L, ...)
-    head.matrix(x, n = n, ...)
+{
+    stopifnot(isScalar(n))
+    n <- if (n < 0L) max(nobs(x) + n, 0L) else min(n, nobs(x))
+    x[seq_len(n), , drop = FALSE]
+}
 
 tail.epidataCS <- function (x, n = 6L, ...)
 {
-    # ugly hack for tail.matrix because I don't want to register a
-    # dim-method for class "epidataCS"
-    nrow <- function (x) base::nrow(x$events)
-    my.tail.matrix <- tail.matrix
-    environment(my.tail.matrix) <- environment()
-    ##<- such that the function uses my local nrow definition
-    my.tail.matrix(x, n = n, addrownums=FALSE, ...)
+    stopifnot(isScalar(n))
+    nrx <- nobs(x)
+    n <- if (n < 0L) max(nrx + n, 0L) else min(n, nrx)
+    x[seq.int(to = nrx, length.out = n), , drop = FALSE]
 }
 
 
@@ -272,7 +275,7 @@ permute.epidataCS <- function (x, what = c("time", "space"), keep)
 
 print.epidataCS <- function (x, n = 6L, digits = getOption("digits"), ...)
 {
-    print.epidataCS_header(
+    print_epidataCS_header(
         timeRange = c(x$stgrid$start[1L], x$stgrid$stop[nrow(x$stgrid)]),
         bbox = bbox(x$W),
         nBlocks = length(unique(x$stgrid$BLOCK)),
@@ -301,7 +304,7 @@ print.epidataCS <- function (x, n = 6L, digits = getOption("digits"), ...)
     invisible(x)
 }
 
-print.epidataCS_header <- function (timeRange, bbox, nBlocks, nTiles,
+print_epidataCS_header <- function (timeRange, bbox, nBlocks, nTiles,
                                     digits = getOption("digits"))
 {
     bboxtxt <- paste(
@@ -351,7 +354,7 @@ summary.epidataCS <- function (object, ...)
 
 print.summary.epidataCS <- function (x, ...)
 {
-    print.epidataCS_header(timeRange = x$timeRange, bbox = x$bbox,
+    print_epidataCS_header(timeRange = x$timeRange, bbox = x$bbox,
                            nBlocks = x$nBlocks, nTiles = length(x$tileTable))
     cat("Overall number of events: ", x$nEvents, " (",
         if (x$nTypes==1) "single type" else paste(x$nTypes, "types"),
