@@ -1,13 +1,14 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Auxiliary functions for operations on spatial data
 ###
-### Copyright (C) 2009-2015 Sebastian Meyer
-### $Revision: 2142 $
-### $Date: 2018-05-14 15:03:36 +0200 (Mon, 14. May 2018) $
+### Copyright (C) 2009-2015,2018,2021-2023  Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
+###
+### $Revision: 2963 $
+### $Date: 2023-03-13 23:24:10 +0100 (Mon, 13. Mar 2023) $
 ################################################################################
 
 
@@ -18,7 +19,7 @@ discpoly <- function (center, radius, npoly = 64,
                       hole = FALSE)
 {
     class <- match.arg(class)
-    if (class == "owin") { # use spatstat::disc
+    if (class == "owin") { # use spatstat.geom::disc
         res <- disc(radius=radius, centre=center, mask=FALSE, npoly=npoly)
         if (hole) {
             res$bdry[[1]]$x <- rev(res$bdry[[1]]$x)
@@ -30,15 +31,17 @@ discpoly <- function (center, radius, npoly = 64,
 
     ## do it myself for the "Polygon" and "gpc.poly" classes
     stopifnot(radius > 0, isScalar(npoly), npoly > 2)
-    theta <- seq(2*pi, 0, length = npoly+1)[-(npoly+1)]   # for clockwise order
+    theta <- seq(2*pi, 0, length.out = npoly+1)[-(npoly+1)]   # for clockwise order
     if (hole) theta <- rev(theta)   # for anticlockwise order
     x <- center[1] + radius * cos(theta)
     y <- center[2] + radius * sin(theta)
     switch(class,
         "Polygon" = Polygon(cbind(c(x,x[1]),c(y,y[1])), hole=hole),
         "gpc.poly" = {
+            ##gpcWarning()
             pts <- list(list(x=x, y=y, hole=hole))
-            if (isClass("gpc.poly") || requireNamespace("rgeos")) {
+            if (isClass("gpc.poly") ||
+                (gpclibCheck() && requireNamespace("gpclib"))) {
                 new("gpc.poly", pts = pts)
             } else {
                 warning("formal class \"gpc.poly\" not available")
@@ -49,12 +52,16 @@ discpoly <- function (center, radius, npoly = 64,
 }
 
 
-### Wrapper for polyclip or rgeos::gUnaryUnion or maptools::unionSpatialPolygons
+### Wrapper for polyclip or rgeos::gUnaryUnion
 
 unionSpatialPolygons <- function (SpP,
-                                  method = c("rgeos", "polyclip", "gpclib"),
+                                  method = c("rgeos", "polyclip"),
                                   ...)
 {
+    if (identical(method, "gpclib")) {
+        .Deprecated(msg = "method = \"gpclib\" is deprecated; using default")
+        method <- NULL
+    }
     method <- match.arg(method)
     W <- switch(
         method,
@@ -70,63 +77,36 @@ unionSpatialPolygons <- function (SpP,
                 ID="1")
             SpatialPolygons(list(W_Polygons))
         },
-        "rgeos" = rgeos::gUnaryUnion(SpP, ...),
-        "gpclib" = {
-            ## rgeosStatus needed by maptools::unionSpatialPolygons is only
-            ## set in maptools:::.onAttach. Since it is bad practice to do
-            ## library("maptools") in package code (cf. R-exts 1.1.3.1),
-            ## the user has to attach "maptools" manually beforehand
-            if (!"maptools" %in% .packages()) {
-                stop("need 'library(\"maptools\")'; ",
-                     "then call surveillance::unionSpatialPolygons")
-            }
-            gpclibCheck() && maptools::gpclibPermit()
-            maptools::unionSpatialPolygons(
-                SpP, IDs = rep.int(1,length(SpP@polygons)),
-                avoidGEOS = TRUE, ...)
-        })
+        "rgeos" = rgeos::gUnaryUnion(SpP, ...)
+        ## "gpclib" = {
+        ##     gpclibCheck() && maptools::gpclibPermit()
+        ##     maptools::unionSpatialPolygons(
+        ##         SpP, IDs = rep.int(1,length(SpP@polygons)),
+        ##         avoidGEOS = TRUE, ...)
+        ## }
+    )
     ## ensure that W has exactly the same proj4string as SpP
     W@proj4string <- SpP@proj4string
     W
 }
 
 
+### internal implementation of as(W, "owin") from polyCub
+### to avoid upgrade problems with polyCub <= 0.7.1 referring to old spatstat
+### and to avoid calling as(W, "owin") from maptools (depends on load order)
+
+SpP2owin <- function (W, ...) owin(poly = xylist(W), ...)
+
+
 ### Compute distance from points to a polygonal boundary
-## nncross.ppp() calls C-code and is about 20 times faster than
-## bdist.points(), which uses spatstat.utils::distppl() (pure R)
-## minor drawback: the polygonal boundary needs to be transformed to "psp"
 
-bdist <- function (xy, poly)  # poly is polygonal "owin" or "psp" (simEpidataCS)
+## since spatstat 1.56-0, bdist.points() interfaces C-code via
+## spatstat.utils:::distppllmin, which is faster than nncross.ppp()
+bdist <- function (xy, poly)  # poly is a polygonal "owin"
 {
-    if (nrow(xy) > 0L) {
-        nncross.ppp(
-            X = ppp(x = xy[,1L], y = xy[,2L], check = FALSE),
-            Y = if (is.polygonal(poly)) edges(poly, check = FALSE) else poly,
-            what = "dist"
-        )
-    } else {
-       ## spatstat 1.41-1 returns a 0-row _data.frame_ for the trivial case
-       numeric(0L)
-   }
+    bdist.points(ppp(x = xy[,1L], y = xy[,2L], window = poly, check = FALSE))
 }
-
-## 20% faster version directly using spatstat.utils::distppllmin(),
-## which is documented as an internal function and thus cannot be relied on
-## bdist <- function (xy, poly)
-## {
-##     if (nrow(xy) > 0L) {
-##         ll <- if (is.polygonal(poly)) {
-##                   edges(poly, check = FALSE)$ends
-##               } else {
-##                   stopifnot(inherits(poly, "psp"))
-##                   poly$ends
-##               }
-##         spatstat.utils::distppllmin(xy, ll)$min.d
-##     } else {
-##         numeric(0L)
-##     }
-## }
-## Try: bdist(coordinates(imdepi$events), as(imdepi$W, "owin"))
+## Example: bdist(coordinates(imdepi$events), as(imdepi$W, "owin"))
 
 
 ### sample n points uniformly on a disc with radius r
@@ -226,7 +206,7 @@ layout.scalebar <- function (obj, corner = c(0.05, 0.95), scale = 1,
     stopifnot(inherits(obj, "Spatial"))
     BB <- bbox(obj)
     force(labels)  # the default should use the original 'scale' value in km
-    if (identical(FALSE, is.projected(obj))) {
+    if (isFALSE(is.projected(obj, warn = TRUE))) {
         ## 'obj' has longlat coordinates, 'scale' is interpreted in kilometres
         scale <- .scale2longlat(t(rowMeans(BB)), scale)
     }
@@ -266,16 +246,49 @@ layout.scalebar <- function (obj, corner = c(0.05, 0.95), scale = 1,
     rightLL[,1L] - focusLL[,1L]
 }
 
+## internal wrapper for sp::is.projected to catch its (future) sf dependence
+is.projected <- function (obj, warn = FALSE)
+{
+    res <- tryCatch(sp::is.projected(obj), error = identity)
+    if (inherits(res, "error")) {
+        pkg <- if (inherits(res, "packageNotFoundError"))
+                   res$package
+               else if (startsWith(res$message, "sf required"))
+                   ## FIXME: temporarily used by "sp" with evolution status 2
+                   "sf"
+               else stop(res)
+        ## fallback: grep for longlat in (deprecated) Proj.4 representation
+        p4s <- as.character(obj@proj4string@projargs)
+        if (is.na(p4s) || !nzchar(p4s)) {
+            if (warn)
+                warning("could not determine projection status; package ",
+                        sQuote(pkg), " is missing")
+            NA
+        } else {
+            !grepl("longlat", p4s, fixed = TRUE)
+        }
+    } else res
+}
+
+## internal replacement for sp::mapasp using the above is.projected wrapper
+mapasp <- function (data)
+{
+    if (isFALSE(is.projected(data))) {
+        bb <- bbox(data)
+        xlim <- bb[1L,]
+        ylim <- bb[2L,]
+        (diff(ylim)/diff(xlim)) / cos((mean(ylim) * pi)/180)
+    } else "iso"
+}
+
 
 ### determine the total area of a SpatialPolygons object
-## CAVE: sum(sapply(obj@polygons, slot, "area"))
-##       is not correct if the object contains holes
 
 areaSpatialPolygons <- function (obj, byid = FALSE)
 {
-    if (requireNamespace("rgeos", quietly = TRUE)) {
-        rgeos::gArea(obj, byid = byid)
-    } else {
+    ## if (requireNamespace("rgeos", quietly = TRUE)) {
+    ##     rgeos::gArea(obj, byid = byid)
+    ## } else {
         areas <- vapply(
             X = obj@polygons,
             FUN = function (p) sum(
@@ -286,5 +299,49 @@ areaSpatialPolygons <- function (obj, byid = FALSE)
             FUN.VALUE = 0, USE.NAMES = FALSE
         )
         if (byid) setNames(areas, row.names(obj)) else sum(areas)
-    }
+    ## }
+}
+
+
+### build a SpatialGrid of approx. 'n' square cells covering 'bbox(obj)'
+## replacement for maptools::Sobj_SpatialGrid()
+
+makeGrid <- function (obj, n = 128)
+{
+    bb <- bbox(obj)
+    xlim <- bb[1L,]
+    ylim <- bb[2L,]
+    xr <- xlim[[2L]] - xlim[[1L]]
+    yr <- ylim[[2L]] - ylim[[1L]]
+    asp <- if (lscape <- xr > yr) xr/yr else yr/xr
+    n1 <- ceiling(sqrt(n*asp))
+    n2 <- ceiling(n1/asp)
+    size <- (if (lscape) xr else yr) / n1
+    offset <- bb[,1L] + size/2
+    grd <- GridTopology(offset, c(size, size),
+                        if (lscape) c(n1, n2) else c(n2, n1))
+    SpatialGrid(grd, proj4string = obj@proj4string)
+}
+
+if (FALSE) {
+## alternative that usually does not produce square cells,
+## but has the same extent as bbox(obj),
+## similar to sf::st_make_grid(obj, n = magic.dim(.));
+## this would produce different spatial intensity plots than before
+makeGrid <- function (obj, n = 128)
+{
+    bb <- bbox(obj)
+    xlim <- bb[1L,]
+    ylim <- bb[2L,]
+    xr <- xlim[[2L]] - xlim[[1L]]
+    yr <- ylim[[2L]] - ylim[[1L]]
+    if (length(n) == 1) {
+        n <- magic.dim(n)
+        if (xr > yr) n <- rev(n)
+    } else stopifnot(length(n) == 2)
+    size <- c(xr, yr)/n
+    offset <- bb[, 1L] + size/2
+    grd <- GridTopology(offset, size, n)
+    SpatialGrid(grd, proj4string = obj@proj4string)
+}
 }
