@@ -1,7 +1,11 @@
+## need a writable figs/ directory to save selected figures
+OUTDIR <- if (interactive()) tempdir() else "."
+stopifnot(dir.create(file.path(OUTDIR, "figs")))
+
 ###################################################
-### chunk number 1: 
+### chunk number 1:
 ###################################################
-library(surveillance)
+library("surveillance")
 options(width=70)
 options("prompt"="R> ")
 set.seed(1234)
@@ -9,7 +13,7 @@ set.seed(1234)
 opendevice <- function(horizontal=TRUE,width=7,height=4,...) {
   #Do it for postscript instead  -- who uses postscript these days??
   args <- list(...)
-  args$file <- sub(".pdf",".eps",args$file)
+  args$file <- file.path(OUTDIR, sub("\\.pdf$",".eps",args$file))
   args$width <- width
   args$height <- height
   args$horizontal <- FALSE
@@ -19,18 +23,9 @@ opendevice <- function(horizontal=TRUE,width=7,height=4,...) {
 }
 
 
-
 ###################################################
-### chunk number 2: K1
+### chunk number 3:
 ###################################################
-data("ha")
-plot(aggregate(ha),main="Hepatitis A in Berlin 2001-2006")
-
-
-###################################################
-### chunk number 3: 
-###################################################
-cat("Info: I need a writable figs/ directory in getwd()\n")
 opendevice(file="figs/002.pdf")
 data("ha")
 plot(aggregate(ha),main="Hepatitis A in Berlin 2001-2006")
@@ -38,16 +33,15 @@ dev.off()
 
 
 ###################################################
-### chunk number 4: 
+### chunk number 4:
 ###################################################
-sps <- sim.pointSource(p = 0.99, r = 0.5, length = 400, 
-     A = 1, alpha = 1, beta = 0, phi = 0, frequency = 1, 
+sps <- sim.pointSource(p = 0.99, r = 0.5, length = 400,
+     A = 1, alpha = 1, beta = 0, phi = 0, frequency = 1,
      state = NULL, K = 1.7)
-plot(sps,xaxis.years=FALSE)
 
 
 ###################################################
-### chunk number 5: 
+### chunk number 5:
 ###################################################
 opendevice(file="figs/003.pdf")
 plot(sps,xaxis.years=FALSE,legend.opts=list(x="topleft"))
@@ -55,32 +49,16 @@ dev.off()
 
 
 ###################################################
-### chunk number 6: HAB662 eval=FALSE
-###################################################
-## ha.b662 <- algo.bayes(aggregate(ha), control = list(range = 209:290, b = 2, w = 6, alpha = 0.01))
-## plot(ha.b662, firstweek=1, startyear = 2005)
-
-
-###################################################
-### chunk number 7: 
+### chunk number 7:
 ###################################################
 ha.b662 <- algo.bayes(aggregate(ha), control = list(range = 209:290, b = 2, w = 6, alpha = 0.01))
-plot(ha.b662, firstweek=1, startyear = 2005)
 opendevice(file="figs/hab662.pdf")
 plot(ha.b662, firstweek=1, startyear = 2005,legend.opts=list(x="topleft",horiz=TRUE))
 dev.off()
 
 
 ###################################################
-### chunk number 8: FACDC eval=FALSE
-###################################################
-## cntrl <- list(range = 300:400, m = 1, w = 3, b = 5, alpha = 0.01)
-## sps.cdc <- algo.cdc(sps, control = cntrl)
-## sps.farrington <- algo.farrington(sps, control = cntrl)
-
-
-###################################################
-### chunk number 9: 
+### chunk number 9:
 ###################################################
 cntrl <- list(range = 300:400, m = 1, w = 3, b = 5, alpha = 0.01)
 sps.cdc <- algo.cdc(sps, control = cntrl)
@@ -88,7 +66,7 @@ sps.farrington <- algo.farrington(sps, control = cntrl)
 
 
 ###################################################
-### chunk number 10: 
+### chunk number 10:
 ###################################################
 opendevice(file="figs/farringtoncdc.pdf")
 par(mfcol = c(1, 2),cex=0.8)
@@ -98,14 +76,7 @@ dev.off()
 
 
 ###################################################
-### chunk number 11: CUSUM eval=FALSE
-###################################################
-## kh <- find.kh(ARLa=500,ARLr=7)
-## ha.cusum <- algo.cusum(aggregate(ha),control=list(k=kh$k,h=kh$h,m="glm",trans="rossi",range=209:290))
-
-
-###################################################
-### chunk number 12: 
+### chunk number 12:
 ###################################################
 opendevice(file="figs/hacusum.pdf")
 kh <- find.kh(ARLa=500,ARLr=7)
@@ -118,15 +89,15 @@ beta <- coef(ha.cusum$control$m.glm)
 
 
 ###################################################
-### chunk number 13: 
+### chunk number 13:
 ###################################################
 print(algo.quality(ha.b662))
 
 
 ###################################################
-### chunk number 14: 
+### chunk number 14:
 ###################################################
-#This chunk contains stuff the reader should not see, but which is necessary 
+#This chunk contains stuff the reader should not see, but which is necessary
 #for the visual block to work.
 control = list(
   list(funcName = "rki1"),
@@ -146,14 +117,20 @@ data("k1")
 range = (2*4*52) +  1:length(k1$observed)
 aparv.control <- lapply(control,function(cntrl) { cntrl$range=range;return(cntrl)})
 
+#Auxiliary function to enlarge data
+enlargeData <- function(disProgObj, range = 1:156, times = 1){
+  disProgObj$observed <- c(rep(disProgObj$observed[range], times), disProgObj$observed)
+  disProgObj$state <- c(rep(disProgObj$state[range], times), disProgObj$state)
+  return(disProgObj)
+}
+
 #Outbreaks
-outbrks <- c("m1", "m2", "m3", "m4", "m5", "q1_nrwh", "q2", 
+outbrks <- c("m1", "m2", "m3", "m4", "m5", "q1_nrwh", "q2",
               "s1", "s2", "s3", "k1", "n1", "n2", "h1_nrwrp")
 
 #Load and enlarge data.
 outbrks <- lapply(outbrks,function(name) {
-  #Load with data
-  eval(substitute(data(name),list(name=name)))
+  data(list=name)
   enlargeData(get(name),range=1:(4*52),times=2)
 })
 
@@ -163,19 +140,6 @@ surv.one <- function(outbrk) {
 }
 
 
-
-###################################################
-### chunk number 15:  eval=FALSE
-###################################################
-## #Apply function to one
-## surv.one <- function(outbrk) {
-##   algo.compare(algo.call(outbrk,control=aparv.control))
-## }
-## 
-## algo.summary(lapply(outbrks, surv.one))
-## 
-
-
 ###################################################
 ### chunk number 16: ALGOSUMMARY
 ###################################################
@@ -183,7 +147,7 @@ res <- algo.summary(lapply(outbrks,surv.one))
 
 
 ###################################################
-### chunk number 17: 
+### chunk number 17:
 ###################################################
 print(res,digits=3)
 
@@ -202,47 +166,37 @@ print(res,digits=3)
 ##                                 populationFrac= "matrix",
 ##                                 map = "SpatialPolygonsDataFrame",
 ##                                 control = "list"))
-## 
+##
 
 
 ###################################################
-### chunk number 19: HA eval=FALSE
+### chunk number 20:
 ###################################################
-## shp <- system.file("shapes/berlin.shp",package="surveillance")
-## ha <- disProg2sts(ha, map=readShapePoly(shp,IDvar="SNAME"))
-## plot(ha,type=observed ~ 1 | unit)
-## 
 
+## import shapefile as "SpatialPolygonsDataFrame"
+shp <- system.file("shapes/berlin.shp",package="surveillance")
+if (requireNamespace("maptools")) { # deprecated package
+    map <- maptools::readShapePoly(shp, IDvar = "SNAME")
+} else { # replacement code
+    map <- sf::as_Spatial(sf::st_read(shp, stringsAsFactors = TRUE, quiet = TRUE))
+    row.names(map) <- as.character(map$SNAME)
+}
+## convert to "sts" class
+ha.sts <- disProg2sts(ha, map = map)
+## or simply load the prepared object from the package: data("ha.sts")
 
-###################################################
-### chunk number 20: 
-###################################################
 opendevice(file="figs/ha-1unit.pdf",width=7,height=7)
 par(mar=c(0,0,0,0))
-shp <- system.file("shapes/berlin.shp",package="surveillance")
-ha <- disProg2sts(ha, map=readShapePoly(shp,IDvar="SNAME"))
-plot(ha,type=observed ~ 1 | unit)
-
+plot(ha.sts,type=observed ~ 1 | unit)
 dev.off()
 
 
 ###################################################
-### chunk number 21: HA:MAP eval=FALSE
-###################################################
-## ha4 <- aggregate(ha[,c("pank","mitt","frkr","scho","chwi","neuk")],nfreq=13)
-## ha4.cusum <- cusum(ha4,control=list(k=1.5,h=1.75,m="glm",trans="rossi",range=52:73))
-## #ha4.b332 <- bayes(ha4,control=list(range=52:73,b=2,w=3,alpha=0.01/6))
-## plot(ha4.cusum,type=observed ~ time | unit)
-
-
-###################################################
-### chunk number 22: 
+### chunk number 22:
 ###################################################
 opendevice(file="figs/ha-timeunit.pdf",width=7,height=5)
-ha4 <- aggregate(ha[,c("pank","mitt","frkr","scho","chwi","neuk")],nfreq=13)
+ha4 <- aggregate(ha.sts[,c("pank","mitt","frkr","scho","chwi","neuk")],nfreq=13)
 ha4.cusum <- cusum(ha4,control=list(k=1.5,h=1.75,m="glm",trans="rossi",range=52:73))
 #ha4.b332 <- bayes(ha4,control=list(range=52:73,b=2,w=3,alpha=0.01/6))
 plot(ha4.cusum,type=observed ~ time | unit)
 dev.off()
-
-
